# Generated by Django 4.0.2 on 2022-07-14 19:53

from django.db import migrations, models
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('shaarpy', '0005_alter_links_date_created'),
    ]

    operations = [
        migrations.AlterField(
            model_name='links',
            name='date_created',
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
    ]
