{% extends "base.html" %}
{% load i18n %}
{% load shaarpy_extras %}
<title>{% block title %}{{ SHAARPY_NAME }} :: {% trans 'Tags Cloud' %}{% endblock %}</title>
{% block og_title %}{% trans 'Tags Cloud' %}{% endblock %}
{% block content %}
<div class="col-xs-8 col-md-8 col-lg-8 offset-xs-2 offset-md-2 offset-lg-2 mt-3">
  <h1><i class="fas fa-tags"></i> {% trans "Tags Cloud" %}</h1>
{% for key, value in tags.items %}
    {% if key %}
    <a href="{% url 'links_by_tag_list' key %}" role="button" class="p-3 m-2 btn btn-outline-dark position-relative">
      {{ key }}
      <span class="position-absolute top-0 start-100 translate-middle badge rounded-pill bg-danger">
        {{ value }}
      </span>
    </a>
    {% endif %}
{% endfor %}
</div>
{% endblock %}
