# coding: utf-8
"""
    ShaarPy :: AppConfig
"""

from django.apps import AppConfig


class ShaarpyConfig(AppConfig):
    name = 'shaarpy'
    verbose_name = "ShaarPy"
    default_auto_field = 'django.db.models.AutoField'
