{% extends "base.html" %}
{% load i18n %}
{% block title %}{{ SHAARPY_NAME }} - 404{% endblock %}
{% block content %}
    <div class="container-fluid">
        <div class="row">
            <div class="footer d-flex align-items-center justify-content-center">
                <h1>404</h1>
            </div>
            <div class="footer d-flex align-items-center justify-content-center">
                <p>{% trans 'Page Not Found' %}</p>
            </div>
        </div>
    </div>
{% endblock %}
