# Generated by Django 4.0.1 on 2022-01-26 12:25

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('shaarpy', '0002_alter_links_options_links_sticky'),
    ]

    operations = [
        migrations.AddField(
            model_name='links',
            name='url_hashed',
            field=models.URLField(blank=True, max_length=2048, null=True),
        ),
        migrations.AlterField(
            model_name='links',
            name='id',
            field=models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID'),
        ),
    ]
