# Generated by Django 4.2.8 on 2023-12-29 15:22

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('shaarpy', '0006_alter_links_date_created'),
    ]

    operations = [
        migrations.AlterField(
            model_name='links',
            name='tags',
            field=models.CharField(blank=True, max_length=255, null=True, validators=[django.core.validators.RegexValidator('^[0-9a-zA-Z\\u3131-\\uD79D\\u1100-\\u11FF\\u3130-\\u318F\\uA960-\\uA97F\\uAC00-\\uD7AF\\uD7B0-\\uD7FF,]*$', 'Only alphanumeric characters are allowed.')]),
        ),
    ]
