# Generated by Django 4.0.1 on 2022-01-28 20:52

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('shaarpy', '0004_alter_links_url_hashed'),
    ]

    operations = [
        migrations.AlterField(
            model_name='links',
            name='date_created',
            field=models.DateTimeField(auto_now_add=True),
        ),
    ]
