# Generated by Django 4.0.1 on 2022-01-10 19:59

import datetime
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Links',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('tags', models.CharField(blank=True, max_length=255, null=True)),
                ('url', models.URLField(blank=True, max_length=2048, null=True)),
                ('title', models.CharField(max_length=255, blank=True, null=True)),
                ('text', models.TextField(blank=True, null=True)),
                ('private', models.BooleanField(default=False)),
                ('image', models.TextField(null=True, blank=True)),
                ('video', models.TextField(null=True, blank=True)),
                ('date_created', models.DateTimeField(default=datetime.datetime.now)),
            ],
            options={
                'verbose_name_plural': 'Links',
                'ordering': ['-date_created'],
            },
        ),
    ]
